import React from 'react';
import { P, Code, A, H2, Hr, H3, Div } from '@cloudflare/elements';

export default ({ ExamplePreview, PropTable, PropRow, snippetScope }) => {
  return (
    <>
      <P fontWeight={400} mt={0} mb={3} fontSize={4}>
        Loading components allow you to present the user with UI while data is
        being fetched.
      </P>

      <P>
        SkeletonBlock components allow you to quickly mimic the layout of a UI
        when the data is not ready yet.
      </P>
      <ExamplePreview
        scope={{ ...snippetScope }}
        bgColor="white"
        code={`<Div bg="white" p={3}><SkeletonBlock /></Div>`}
      />

      <P>
        In essence it is just a box that you can set width and height on and it
        will be shown as a light gray box on the page.
      </P>
      <ExamplePreview
        scope={{ ...snippetScope }}
        bgColor="white"
        code={`<Div bg="white" p={3}><SkeletonBlock height={40} width={120} /></Div>`}
      />

      <P>
        You can create realistic layouts using the same components as you would
        normally use. Creating more complex layouts with SkeletonBlock's help
        avoiding layout thrashing when the data is received and can be populated
        and the skeleton layout is replace with the real layout.
      </P>
      <ExamplePreview
        scope={{ ...snippetScope }}
        bgColor="white"
        code={`<Div bg="white" p={3}><Div display='flex' mb={3}>
    <SkeletonBlock height={40} mr={3} />
    <SkeletonBlock height={40} />
    </Div>
    <SkeletonBlock height={40} /></Div>`}
      />

      <P>
        If you don't require an entire layout but instead just want to show a
        user that some action is currently pending to be completed a loading
        spinner may be a better option.
      </P>
      <ExamplePreview scope={{ ...snippetScope }} code={`<Loading/>`} />

      <P>
        You can change the size of the Loading component by passing in the size
        prop
      </P>
      <ExamplePreview
        scope={{ ...snippetScope }}
        code={`<Loading size="2x" />`}
      />

      <Hr
        my={5}
        borderTop="0px"
        borderRight="0px"
        borderLeft="0px"
        borderBottom="1px solid"
        borderColor="gray.8"
      />

      <H2>SkeletonBlock props</H2>

      <Div mb={5}>
        <H3 mb={1}>Styling</H3>
        <P fontSize={2} mt={0}>
          This component supports all the{' '}
          <A color="inherit" href="https://styled-system.com/table">
            Styled System
          </A>{' '}
          props.
        </P>
      </Div>

      <Div>
        <H3 mb={1}>Custom</H3>
        <P fontSize={2} mb={3} mt={0}>
          There are no custom props for this component.
        </P>
      </Div>

      <Div mt={5} mb={5}>
        <H3 mb={1}>Events</H3>
        <P fontSize={2} mb={3} mt={0}>
          There are no custom events for this component
        </P>
      </Div>

      <Hr
        my={5}
        borderTop="0px"
        borderRight="0px"
        borderLeft="0px"
        borderBottom="1px solid"
        borderColor="gray.8"
      />

      <H2>Loading props</H2>

      <Div mb={5}>
        <H3 mb={1}>Styling</H3>
        <P fontSize={2} mt={0}>
          This component supports all the{' '}
          <A color="inherit" href="https://styled-system.com/table">
            Styled System
          </A>{' '}
          props.
        </P>
      </Div>

      <Div>
        <H3 mb={1}>Custom</H3>
        <P fontSize={2} mb={3} mt={0}>
          These props are custom to this component and are based on the{' '}
          <A
            color="inherit"
            href="https://reactjs.org/docs/components-and-props.html"
          >
            React props
          </A>{' '}
          concept.
        </P>

        <PropTable cols={['Name', 'Type', 'Default', 'Description']}>
          <PropRow
            name="size"
            type="string"
            defaultVal="1x"
            description={
              <>
                Can be one of the following values{' '}
                <Code>1x, 1.5x, 2x, 2.5x, 3x, 3.5x, 4x</Code>
              </>
            }
          />
          <PropRow
            name="color"
            type="string"
            defaultVal="gray.5"
            description={<>The color used for the component</>}
          />
        </PropTable>
      </Div>

      <Div mt={5} mb={5}>
        <H3 mb={1}>Events</H3>
        <P fontSize={2} mb={3} mt={0}>
          There are no custom events for this component.
        </P>
      </Div>
    </>
  );
};
