import React, { useEffect, useRef } from 'react';
import { Trans } from '@cloudflare/intl-react';
import { VisuallyHiddenSpan } from '@cloudflare/component-visually-hidden';
import { theme } from '@cloudflare/style-const';
import { createComponent } from '@cloudflare/style-container';
import { Div } from '@cloudflare/elements';
var SquareCanvas = createComponent(_ref => {
  var {
    side
  } = _ref;
  return {
    width: "".concat(side, "px"),
    height: "".concat(side, "px")
  };
}, 'canvas');
var DEFAULT_HEIGHT = 15; // px

var ARC_THICKNESS = 0.151; // relative to diameter

var ANGLE_STEP = Math.PI / 30; // radians/frame (regulates animation speed)

var MIN_ARC_LENGTH = 0.01; // ratio of full circle

var MAX_ARC_LENGTH = 0.8; // ratio of full circle

function Loading(_ref2) {
  var {
    color,
    size: layoutSize = '1x'
  } = _ref2;
  var canvas = useRef(null);
  var size = Math.round(DEFAULT_HEIGHT * Number(layoutSize.replace('x', '')));
  useEffect(() => {
    if (canvas.current) {
      var _canvas$current;

      var ctx = (_canvas$current = canvas.current) === null || _canvas$current === void 0 ? void 0 : _canvas$current.getContext('2d');

      if (!ctx) {
        return; // canvas not available (f.e. in tests)
      }

      ctx.resetTransform(); // Keep it crisp on retina devices

      var scaleFactor = window.devicePixelRatio || 1;
      ctx.scale(scaleFactor, scaleFactor);
      var radius = size / 2;
      var arcThickness = Math.floor(size * ARC_THICKNESS);
      var angleStep = ANGLE_STEP;
      var arcLengthRange = [MIN_ARC_LENGTH, MAX_ARC_LENGTH].map(p => p * 2 * Math.PI);
      var arcProps = [0, // center X
      0, // center Y
      radius - arcThickness / 2 // radius
      ];
      ctx.translate(radius, radius); // center at (0,0)

      ctx.strokeStyle = color || theme.colors.gray[5];
      ctx.lineWidth = arcThickness;
      var arcLength = 0;
      var fwd = true;
      var rafId;

      var onFrame = () => {
        ctx.clearRect(-radius, -radius, size, size);
        ctx.rotate(angleStep);
        var halfArcLength = Math.max(0, arcLength / 2);
        ctx.beginPath();
        ctx.arc(...arcProps, -halfArcLength, halfArcLength);
        ctx.stroke();

        if (arcLength <= arcLengthRange[0]) {
          fwd = true;
        }

        if (arcLength >= arcLengthRange[1]) {
          fwd = false;
        }

        arcLength += (fwd ? 1 : -1) * angleStep;
        rafId = requestAnimationFrame(onFrame);
      };

      rafId = requestAnimationFrame(onFrame);
      return () => {
        if (rafId) {
          // stop frame ticker
          cancelAnimationFrame(rafId);
        }
      };
    }
  }, [color, size]);
  var scaledHeight = size * (window.devicePixelRatio || 1);
  return /*#__PURE__*/React.createElement(Div, null, /*#__PURE__*/React.createElement(SquareCanvas, {
    innerRef: canvas,
    side: size,
    width: scaledHeight,
    height: scaledHeight
  }), /*#__PURE__*/React.createElement(VisuallyHiddenSpan, null, /*#__PURE__*/React.createElement(Trans, {
    id: "accessibility.content_loading",
    _: "Content loading"
  })));
}

export default Loading;